==> haskell-shakespeare-2.1.0.1-98-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shakespeare
version:              2.1.0.1
visibility:           public
id:                   shakespeare-2.1.0.1-5RILvIEoiKPDNjuLhOJq66
key:                  shakespeare-2.1.0.1-5RILvIEoiKPDNjuLhOJq66
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/shakespearean-templates
synopsis:             A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.

    Shakespeare templates can be used inline with a quasi-quoter or in an external file.

    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.

    Packages that use this: xml-hamlet

    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.

category:             Web, Yesod
abi:                  6df24216e5059a2de301f37c07f2a028
exposed:              True
exposed-modules:
    Text.Cassius Text.Cassius.Ordered Text.Coffee Text.Hamlet
    Text.Hamlet.RT Text.Hamlet.Runtime Text.Internal.Cassius
    Text.Internal.Css Text.Internal.CssCommon Text.Internal.Lucius
    Text.Julius Text.Lucius Text.Lucius.Ordered Text.Roy
    Text.Shakespeare Text.Shakespeare.Base Text.Shakespeare.I18N
    Text.Shakespeare.Text Text.TypeScript

hidden-modules:       Text.Hamlet.Parse Text.MkSizeType Text.IndentToBrace
import-dirs:          /usr/lib/ghc-9.4.8/site-local/shakespeare-2.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/shakespeare-2.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/shakespeare-2.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shakespeare
hs-libraries:         HSshakespeare-2.1.0.1-5RILvIEoiKPDNjuLhOJq66
depends:
    aeson-2.1.2.1-GOr0sGsn8HVJzt9KhewtB0 base-4.17.2.1
    blaze-html-0.9.2.0-7rraM1lSLOl2LrVAS4qxq6
    blaze-markup-0.8.3.0-EXIdF6gaJs7HROOmQDdLmZ bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.7.1 exceptions-0.10.5
    file-embed-0.0.15.0-7OnjuFj6gBM9fqBKJCVXdU ghc-prim-0.9.1
    parsec-3.1.16.1 process-1.6.18.0
    scientific-0.3.7.0-6O6FbUTzbTcBhAh2dckDIt template-haskell-2.19.0.0
    text-2.0.2 th-lift-0.8.5-3bCWMcLwp8dEXoRnv4Yrhx time-1.12.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-Jl6TkouWI2i1D1jczNV0uv
    vector-0.13.2.0-F0gUvA5SUIr11j4RVHYOTP

haddock-interfaces:   /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html:         /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shakespeare-2.1.0.1-101-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shakespeare
version:              2.1.0.1
visibility:           public
id:                   shakespeare-2.1.0.1-GM1d5JK2NZvLaPL2UA0TeM
key:                  shakespeare-2.1.0.1-GM1d5JK2NZvLaPL2UA0TeM
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/shakespearean-templates
synopsis:             A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.

    Shakespeare templates can be used inline with a quasi-quoter or in an external file.

    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.

    Packages that use this: xml-hamlet

    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.

category:             Web, Yesod
abi:                  d3522f4441b06631fa50558475f5cb9f
exposed:              True
exposed-modules:
    Text.Cassius Text.Cassius.Ordered Text.Coffee Text.Hamlet
    Text.Hamlet.RT Text.Hamlet.Runtime Text.Internal.Cassius
    Text.Internal.Css Text.Internal.CssCommon Text.Internal.Lucius
    Text.Julius Text.Lucius Text.Lucius.Ordered Text.Roy
    Text.Shakespeare Text.Shakespeare.Base Text.Shakespeare.I18N
    Text.Shakespeare.Text Text.TypeScript

hidden-modules:       Text.Hamlet.Parse Text.MkSizeType Text.IndentToBrace
import-dirs:          /usr/lib/ghc-9.4.8/site-local/shakespeare-2.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/shakespeare-2.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/shakespeare-2.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shakespeare
hs-libraries:         HSshakespeare-2.1.0.1-GM1d5JK2NZvLaPL2UA0TeM
depends:
    aeson-2.1.2.1-LS8mizUYnpf1U9zpV4sjcf base-4.17.2.1
    blaze-html-0.9.2.0-7T5tBdPknWXDUJ5NeSXWzj
    blaze-markup-0.8.3.0-4zGQB5UMO8P5hF725cGajZ bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.7.1 exceptions-0.10.5
    file-embed-0.0.15.0-7OnjuFj6gBM9fqBKJCVXdU ghc-prim-0.9.1
    parsec-3.1.16.1 process-1.6.18.0
    scientific-0.3.7.0-I6iMwi20J4G9Jw2tSdEPEK template-haskell-2.19.0.0
    text-2.0.2 th-lift-0.8.5-3bCWMcLwp8dEXoRnv4Yrhx time-1.12.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-vB8Yx6KwyeBrT13JKFJ0i
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8

haddock-interfaces:   /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html:         /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
